@@ -4,7 +4,7 @@ import marshmallow as ma
 from marshmallow.fields import Nested
 from marshmallow_sqlalchemy import SQLAlchemyAutoSchema, auto_field
 from sqlalchemy import Column, Integer, String, ForeignKey
-from sqlalchemy.orm import relationship
+from sqlalchemy.orm import relationship, deferred
 from sqlalchemy.ext.hybrid import hybrid_property
 from flask_sqlalchemy import SQLAlchemy
 
@@ -272,3 +272,137 @@ class TestSmartRelationshipsMixin:
                 "concat": "a b",
             },
         )
+
+    def test_excluded_field(self):
+        class ExcludeSchema(SmartRelationshipsMixin, ma.Schema):
+            class Meta:
+                exclude = ("d",)
+
+            a = ma.fields.String(metadata={"exclude": False})
+            b = ma.fields.String(metadata={"exclude": True})
+            c = ma.fields.String()
+            d = ma.fields.String()
+
+        s = {"a": "A", "b": "B", "c": "C", "d": "D"}
+
+        TestCase().assertDictEqual(
+            ExcludeSchema().dump(s),
+            {
+                "a": "A",
+                "c": "C",
+            },
+        )
+        TestCase().assertDictEqual(
+            ExcludeSchema(only=["a"]).dump(s),
+            {
+                "a": "A",
+            },
+        )
+        TestCase().assertDictEqual(
+            ExcludeSchema(only=["b"]).dump(s),
+            {
+                "b": "B",
+            },
+        )
+        TestCase().assertDictEqual(
+            ExcludeSchema(only=["+b"]).dump(s),
+            {
+                "a": "A",
+                "b": "B",
+                "c": "C",
+            },
+        )
+        TestCase().assertDictEqual(
+            ExcludeSchema(only=["+c"]).dump(s),
+            {
+                "a": "A",
+                "c": "C",
+            },
+        )
+        TestCase().assertDictEqual(ExcludeSchema(only=["c"], exclude=["c"]).dump(s), {})
+        TestCase().assertDictEqual(
+            ExcludeSchema(only=["+c"], exclude=["c"]).dump(s),
+            {
+                "a": "A",
+            },
+        )
+        TestCase().assertDictEqual(
+            ExcludeSchema(only=["a", "+b"]).dump(s),
+            {
+                "a": "A",
+                "b": "B",
+            },
+        )
+
+    def test_nested_excluded_field(self):
+        class ParentExcludeSchema(SmartRelationshipsMixin, ma.Schema):
+            child = ma.fields.Nested("ChildExcludeSchema")
+
+        class ChildExcludeSchema(SmartRelationshipsMixin, ma.Schema):
+            a = ma.fields.String(metadata={"exclude": False})
+            b = ma.fields.String(metadata={"exclude": True})
+
+            parent = ma.fields.Nested("ParentExcludeSchema")
+
+        p = {"child": {"a": "A", "b": "B"}}
+        TestCase().assertDictEqual(ParentExcludeSchema().dump(p), {})
+        TestCase().assertDictEqual(
+            ParentExcludeSchema(only=["child"]).dump(p),
+            {
+                "child": {
+                    "a": "A",
+                },
+            },
+        )
+        TestCase().assertDictEqual(
+            ParentExcludeSchema(only=["child.a"]).dump(p),
+            {
+                "child": {
+                    "a": "A",
+                },
+            },
+        )
+        TestCase().assertDictEqual(
+            ParentExcludeSchema(only=["child.b"]).dump(p),
+            {
+                "child": {
+                    "b": "B",
+                },
+            },
+        )
+        TestCase().assertDictEqual(
+            ParentExcludeSchema(only=["child.+b"]).dump(p),
+            {
+                "child": {
+                    "a": "A",
+                    "b": "B",
+                },
+            },
+        )
+        TestCase().assertDictEqual(
+            ParentExcludeSchema(only=["child.a", "child.+b"]).dump(p),
+            {
+                "child": {
+                    "a": "A",
+                    "b": "B",
+                },
+            },
+        )
+
+    def test_deferred_field(self):
+        class DeferredModel(db.Model):
+            pk = db.Column(db.Integer, primary_key=True)
+            a = db.Column(db.String)
+            b = deferred(db.Column(db.String))
+
+        class DeferredSchema(SmartRelationshipsMixin, SQLAlchemyAutoSchema):
+            class Meta:
+                model = DeferredModel
+
+        d = DeferredModel(pk=1, a="A", b="B")
+
+        TestCase().assertDictEqual(DeferredSchema().dump(d), {"pk": 1, "a": "A"})
+        TestCase().assertDictEqual(
+            DeferredSchema(only=["+b"]).dump(d), {"pk": 1, "a": "A", "b": "B"}
+        )
+        TestCase().assertDictEqual(DeferredSchema(only=["b"]).dump(d), {"b": "B"})
